@@ -4,7 +4,7 @@
 # imports.
 from syst3m.v1.classes.system import User, Group
 from syst3m.v1.classes.color import color, symbol
-from syst3m.v1.classes.defaults import defaults, kill
+from syst3m.v1.classes.defaults import defaults, kill, processes
 from syst3m.v1.classes.env import env
 from syst3m.v1.classes.disks import disks
 from syst3m.v1.classes import utils, console, objects, browser
