@@ -10,7 +10,7 @@ import platform
 def kill(
 	# the process id.
 	pid=None, 
-	# sudo required.
+	# root permission required.
 	sudo=False,
 	# loader.
 	loader=True,
@@ -20,8 +20,7 @@ def kill(
 		loader_ = syst3m.console.Loader(f"Killing process {pid}.")
 	else:
 		log_level = -1
-	if sudo: _sudo_ = "sudo "
-	else: _sudo_ = ""
+	_sudo_ = Formats.Boolean(sudo).convert(true="sudo ", false="")
 	output = syst3m.utils.__execute_script__(f"{_sudo_}kill {pid}")
 	if "terminated" in output:
 		if loader: loader_.stop()
@@ -30,6 +29,32 @@ def kill(
 		if loader: loader_.stop(success=False)
 		return r3sponse.error_response(f"Failed to stop process {pid}, error: {output}", log_level=log_level)
 
+# list all processes.
+def processes(
+	# root permission.
+	sudo=False,
+	# all processes that include a str.
+	includes=None,
+):
+	_sudo_ = Formats.Boolean(sudo).convert(true="sudo ", false="")
+	if isinstance(includes, str):
+		command = f"""{sudo}ps -ax | grep "{includes}" | """
+	else:
+		command = f"""{sudo}ps -ax | """
+	output = syst3m.utils.__execute_script__(command + """awk '{print $1"|"$2"|"$3"|"$4}' """)
+	processes = {}
+	for line in output.split("\n"):
+		if line not in ["", " "]:
+			pid,tty,_,process = line.split("|")
+			processes[pid] = {
+				"pid":pid,
+				"tty":tty,
+				"process":process,
+			}
+	return r3sponse.sucess_response(f"Successfully listed {len(processes)} processes." {
+		"processes":processes,
+	})
+
 # defaults object class.
 class Defaults(object):
 	def __init__(self):
